/*
 * Copyright 2002-2006 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.springframework.webflow.execution.repository.conversation;

import org.springframework.core.NestedRuntimeException;
import org.springframework.webflow.execution.repository.FlowExecutionRepository;

/**
 * The root of the {@link FlowExecutionRepository} exception hierarchy.
 * Indicates a problem occured either creating, restoring, saving, or
 * invalidating a managed flow execution.
 * 
 * @author Keith Donald
 */
public abstract class ConversationServiceException extends NestedRuntimeException {

	/**
	 * Creates a new flow execution repository exception explicitly noting the
	 * repository that had the problem.
	 * @param message the message
	 */
	public ConversationServiceException(String message) {
		super(message);
	}

	/**
	 * Creates a new flow execution repository exception explicitly noting the
	 * repository that had the problem.
	 * @param message the message
	 * @param cause the root cause of the problem
	 */
	public ConversationServiceException(String message, Throwable cause) {
		super(message, cause);
	}
}